ExtraRelationGraphPairCombinator
================================

.. currentmodule:: pykeen.datasets.ea.combination

.. autoclass:: ExtraRelationGraphPairCombinator
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~ExtraRelationGraphPairCombinator.ALIGNMENT_RELATION_NAME

   .. rubric:: Methods Summary

   .. autosummary::

      ~ExtraRelationGraphPairCombinator.process

   .. rubric:: Attributes Documentation

   .. autoattribute:: ALIGNMENT_RELATION_NAME

   .. rubric:: Methods Documentation

   .. automethod:: process
